@@ -29,16 +29,16 @@ def rsi(datos,venta_rsi,compra_rsi,rsi_periodo,ema_rsi,ema_mediamovil,ema_longit
         # Agregamos el cálculo de la media móvil
         ma_valor = ma_valores.iloc[-1]
         # cruce
-        if float(rsi_valor) > float(venta_rsi) and float(rsi_valor) < float(ma_valor):
+        if rsi_valor > venta_rsi and rsi_valor < ma_valor:
            senial="vender"
-        elif float(rsi_valor) < float(compra_rsi) and float(rsi_valor) > float(ma_valor):
+        elif rsi_valor < compra_rsi and rsi_valor > ma_valor:
             senial="comprar"
         else:
             senial = 'ninguna'
     else:
-        if float(rsi_valor) > float(venta_rsi):
+        if rsi_valor > venta_rsi:
             senial="vender"
-        elif float(rsi_valor) < float(compra_rsi):
+        elif rsi_valor < compra_rsi:
             senial="comprar"
         else:
             senial="ninguna"
@@ -57,15 +57,15 @@ def bb(datos,precio_actual,porcentaje_banda_arriba,porcentaje_banda_abajo, longi
     ultima_banda_superior = banda_superior.iloc[-1]
     ultima_banda_inferior = banda_inferior.iloc[-1]
 
-    xabajo=float(ultima_banda_inferior) + ((float(porcentaje_banda_abajo)/100)*float(ultima_banda_inferior))
-    valorcomprarya=float(xabajo)
+    xabajo=ultima_banda_inferior + ((porcentaje_banda_abajo/100)*ultima_banda_inferior)
+    valorcomprarya=xabajo
 
-    xrriba=float(ultima_banda_superior) - ((float(porcentaje_banda_arriba)/100)*float(ultima_banda_superior))
-    valorgananciavender=float(xrriba)
+    xrriba=ultima_banda_superior - ((porcentaje_banda_arriba/100)*ultima_banda_superior)
+    valorgananciavender=xrriba
 
-    if float(precio_actual) >= float(valorgananciavender):
+    if precio_actual >= valorgananciavender:
         senial="vender"
-    elif float(precio_actual) <= float(valorcomprarya):
+    elif precio_actual <= valorcomprarya:
         senial="comprar"
     else:
         senial="ninguna" 
@@ -91,9 +91,9 @@ def ma(datos, periodo, periodo1, ma_tipo):
     media1=ma_1.iloc[-1]
     media2=ma_2.iloc[-1]
 
-    if float(media1) > float(media2):
+    if media1 > media2:
         senial="comprar"
-    elif float(media1) < float(media2):
+    elif media1 < media2:
         senial="vender"
     else:
         senial = "ninguna"
@@ -219,16 +219,16 @@ def estocastico(df,k_periodo,d_periodo,arriba_k,arriba_d,abajo_k,abajo_d,solo_es
     estocasticok=df["%K"].iloc[-1]
     estocasticod=df["%D"].iloc[-1]
     if solo_estocasticok=="si":
-        if float(estocasticok) >= float(arriba_k):
+        if estocasticok >= arriba_k:
             senial="vender"
-        if float(estocasticok) <= float(abajo_k):
+        if estocasticok <= abajo_k:
             senial="comprar"
         else:
             senial="ninguna"  
     else:
-        if float(estocasticok) >= float(arriba_k) and float(estocasticod) >= float(arriba_d) and float(estocasticok) < float(estocasticod):
+        if estocasticok >= arriba_k and estocasticod >= arriba_d and estocasticok < estocasticod:
             senial="vender"
-        if float(estocasticok) <= float(abajo_k) and float(estocasticod) <= float(abajo_d) and float(estocasticok) > float(estocasticod):
+        if estocasticok <= abajo_k and estocasticod <= abajo_d and estocasticok > estocasticod:
             senial="comprar"
         else:
             senial="ninguna" 
@@ -251,9 +251,9 @@ def ichimoku(data, conversion_line_periods, base_line_periods, leading_span_b_le
     data['leading_span_a'] = leading_span_a
     data['leading_span_b'] = leading_span_b
     data['lagging_span'] = lagging_span
-    if float(tenkan_sen.iloc[-1]) > float(kijun_sen.iloc[-1]):
+    if tenkan_sen.iloc[-1] > kijun_sen.iloc[-1]:
         senial = "comprar"
-    elif float(tenkan_sen.iloc[-1]) < float(kijun_sen.iloc[-1]):
+    elif tenkan_sen.iloc[-1] < kijun_sen.iloc[-1]:
         senial = "vender"
     else:
         senial = "ninguna"
@@ -280,9 +280,9 @@ def macd(df,rapidaema,lentoema,senialperiodo,usar_divergencia,cruce):
         else:
             senial_divergencia = "ninguna"
         # Aplicar señal MACD normal
-        if float(macdb) > float(macdsenial) and float(macdb) < 0 and float(macdsenial) < 0:
+        if macdb > macdsenial and macdb < 0 and macdsenial < 0:
             senial_normal = "comprar"
-        elif float(macdb) < float(macdsenial) and float(macdb) > 0 and float(macdsenial) > 0:
+        elif macdb < macdsenial and macdb > 0 and macdsenial > 0:
             senial_normal = "vender"
         else:
             senial_normal = "ninguna"
@@ -298,9 +298,9 @@ def macd(df,rapidaema,lentoema,senialperiodo,usar_divergencia,cruce):
         else:
             senial=senial_normal
     else:
-        if float(macdb) > 0:
+        if macdb > 0:
             senial = "comprar"
-        elif float(macdb) < 0:
+        elif macdb < 0:
             senial = "vender"
         else:
             senial = "ninguna" 
@@ -320,17 +320,19 @@ def tendencia(df,cualma,ma1,ma2,ma3):
         mavalor2 = df['close'].ewm(span=ma2, min_periods=ma2).mean().iloc[-1]
         mavalor3 = df['close'].ewm(span=ma3, min_periods=ma3).mean().iloc[-1]
 
-    if float(mavalor1) > float(mavalor2) and float(mavalor1) > float(mavalor3):
+    if mavalor1 > mavalor2 and mavalor1 > mavalor3:
         senial="ALCISTA"
 
-    if float(mavalor1) > float(mavalor2) and float(mavalor1) < float(mavalor3):
-        senial="TENDICIA ALCISTA INICIA"
+    elif mavalor1 > mavalor2 and mavalor1 < mavalor3:
+        senial="TENDECIA ALCISTA INICIA"
 
-    if float(mavalor1) < float(mavalor2) and float(mavalor1) < float(mavalor3):
+    elif mavalor1 < mavalor2 and mavalor1 < mavalor3:
         senial="BAJISTA"
 
-    if float(mavalor1) < float(mavalor2) and float(mavalor1) > float(mavalor3):
+    elif mavalor1 < mavalor2 and mavalor1 > mavalor3:
         senial="TENDENCIA BAJISTA INICIA"
+    else:
+        senial="NINGUNA"
 
     return senial
 #-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------
@@ -412,16 +414,16 @@ def dmi(df,period,perioddi,conadx,umbral):
     del df['DX'], df['ATR'], df['TR'], df['-DX'], df['+DX'], df['+DMI'], df['-DMI']
     adxx=df['ADX'].iloc[-1]
     if conadx=="si":
-        if float(masx) > float(menosx) and float(adxx) > float(umbral):
+        if masx > menosx and adxx > umbral:
             senial="comprar"
-        elif float(masx) < float(menosx) and float(adxx) > float(umbral):
+        elif masx < menosx and adxx > umbral:
             senial="vender"
         else:
             senial="ninguna" 
     else:
-        if float(masx) > float(menosx):
+        if masx > menosx:
             senial="comprar"
-        elif float(masx) < float(menosx):
+        elif masx < menosx:
             senial="vender"
         else:
             senial="ninguna" 
@@ -436,9 +438,9 @@ def aroon(df,periodoaron):
     df['dn'] = 100 * df['low'].rolling(periodoaron + 1).apply(lambda x: x.argmin()) / periodoaron
     varriba=df['up'].iloc[-1]
     vabajo=df['dn'].iloc[-1]
-    if float(varriba) > float(vabajo):
+    if varriba > vabajo:
         senial="comprar"
-    elif float(varriba) < float(vabajo):
+    elif varriba < vabajo:
         senial="vender"
     else:
         senial="ninguna" 
@@ -459,9 +461,9 @@ def ce(df, atr_period, atrmulti):
     cierre_Actual=df['close'].iloc[-1]
     compra_Actual=comprach.iloc[-1]
     venta_actual=ventach.iloc[-1]
-    if float(cierre_Actual) > float(compra_Actual):
+    if cierre_Actual > compra_Actual:
         senial="comprar"
-    elif float(cierre_Actual) < float(venta_actual):
+    elif cierre_Actual < venta_actual:
         senial="vender"
     else:
         senial="ninguna"
@@ -492,9 +494,9 @@ def rvi(df, longitud):
     rvi_signal = (rvi + rvi1 + rvi2 + rvi3) / 6
     rvivalor=rvi.iloc[-1]
     rvisenial=rvi_signal.iloc[-1]
-    if float(rvivalor) > float(rvisenial) and float(rvivalor) < 0 and float(rvisenial) < 0:
+    if rvivalor > rvisenial and rvivalor < 0 and rvisenial < 0:
         senial="comprar"
-    elif float(rvivalor) < float(rvisenial) and float(rvisenial) > 0 and float(rvivalor) > 0:
+    elif rvivalor < rvisenial and rvisenial > 0 and rvivalor > 0:
         senial="vender"
     else:
         senial="ninguna" 
@@ -508,9 +510,9 @@ def william_r(df,periodo,venta,compra):
     lowl = df['low'].rolling(periodo).min()
     wr = -100 * ((highh - df['close']) / (highh - lowl))
     v_william=wr.iloc[-1]
-    if float(v_william) > float(venta):
+    if v_william > venta:
         senial="vender"
-    elif float(v_william) < float(compra):
+    elif v_william < compra:
         senial="comprar"
     else:
         senial="ninguna" 
@@ -536,13 +538,13 @@ def kc(df,precio,cual, longitud, multipl, atrlongi,porcentaje_banda_arriba,porce
         kc_lower = df['close'].ewm(span=longitud, min_periods=longitud).mean() - multipl * atr
     kc_arriba=kc_upper.iloc[-1]
     kc_abajo=kc_lower.iloc[-1]
-    xabajokc=float(kc_abajo) + ((float(porcentaje_banda_abajo)/100)*float(kc_abajo))
-    valorcompraryakc=float(xabajokc)
-    xrribakc=float(kc_arriba) - ((float(porcentaje_banda_arriba)/100)*float(kc_arriba))
-    valorgananciavenderkc=float(xrribakc)
-    if float(precio) > float(valorgananciavenderkc):
+    xabajokc=kc_abajo + ((porcentaje_banda_abajo/100)*kc_abajo)
+    valorcompraryakc=xabajokc
+    xrribakc=kc_arriba - ((porcentaje_banda_arriba/100)*kc_arriba)
+    valorgananciavenderkc=xrribakc
+    if precio > valorgananciavenderkc:
         senial="vender"
-    elif float(precio) < float(valorcompraryakc):
+    elif precio < valorcompraryakc:
         senial="comprar"
     else:
         senial="ninguna" 
@@ -564,9 +566,9 @@ def coppock_curve(df, roclargo, roccorto, wma, umbral):
     weights = np.arange(1, wma + 1)
     wma = ROC.rolling(wma).apply(lambda prices: np.dot(prices, weights) / weights.sum(), raw = True)
     valor_cc = wma.iloc[-1]
-    if float(valor_cc) > float(umbral):
+    if valor_cc > umbral:
         senial = "comprar"
-    elif float(valor_cc) < float(-umbral):
+    elif valor_cc < -umbral:
         senial = "vender"
     else:
         senial = "ninguna" 
@@ -584,9 +586,9 @@ def ao(df, corto,largo):
     #restamos los promedios
     ocilador=cor - lar
     valor_ao=ocilador.iloc[-1]
-    if float(valor_ao) > 0:
+    if valor_ao > 0:
         senial="comprar"
-    elif float(valor_ao) < 0:
+    elif valor_ao < 0:
         senial="vender"
     else:
         senial="ninguna" 
@@ -621,4 +623,5 @@ def squeeze_momentum(df, length, mult, lengthKC, multKC, useTrueRange):
             signals.iloc[-1] = 'comprar'
         elif hist.iloc[-1] < 0:
             signals.iloc[-1] = 'vender'
+    
     return signals.iloc[-1]
\ No newline at end of file
